==> activity-center-api-0.5.2-20170315.061928-1-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/ActivityOptionDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto;

import cn.com.duiba.tuia.activity.center.api.common.BaseDto;

/**
 * ClassName: ActivityOptionDto <br/>
 * Function: 活动奖项Dto. <br/>
 * date: 2017年2月24日 下午2:17:46 <br/>
 *
 * @author wubo
 * @version 
 * @since JDK 1.7
 */
public class ActivityOptionDto extends BaseDto {

    private static final long serialVersionUID = -1115120469267768221L;
    private Long              id;                                      // 奖项id
    private Long              activityId;                              // 活动id
    private Integer           activityType;                            // 活动type
    private Long              advertId;                                // 广告id
    private Long              gid;                                     // 广告券id
    private Integer           gtype;                                   // 广告券类型
    private String            prizeType;                               // 奖项类型
    private String            image;                                   // 奖品图片url
    private String            detailImg;                               // 奖品详情图片 url
    private String            title;                                   // 奖品标题
    private Long              stockId;                                 // 剩余奖品数的库存id
    private Integer           stock;                                   // 库存值
    private Integer           stockChange;                             // 库存变化值
    private String            rate;                                    // 概率
    private String            description;                             // 奖品说明
    private String            detailDesc;                              // 奖品详情说明
    private Integer           payload;                                 // 排序权重
    private Integer           hidden;                                  // 奖品说明是否展示
    private Boolean           isDeleted;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Integer getActivityType() {
        return activityType;
    }

    public void setActivityType(Integer activityType) {
        this.activityType = activityType;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getGid() {
        return gid;
    }

    public void setGid(Long gid) {
        this.gid = gid;
    }

    public Integer getGtype() {
        return gtype;
    }

    public void setGtype(Integer gtype) {
        this.gtype = gtype;
    }

    public String getPrizeType() {
        return prizeType;
    }

    public void setPrizeType(String prizeType) {
        this.prizeType = prizeType;
    }

    public String getImage() {
        return image;
    }

    public void setImage(String image) {
        this.image = image;
    }

    public String getDetailImg() {
        return detailImg;
    }

    public void setDetailImg(String detailImg) {
        this.detailImg = detailImg;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Long getStockId() {
        return stockId;
    }

    public void setStockId(Long stockId) {
        this.stockId = stockId;
    }

    public Integer getStock() {
        return stock;
    }

    public void setStock(Integer stock) {
        this.stock = stock;
    }

    public Integer getStockChange() {
        return stockChange;
    }

    public void setStockChange(Integer stockChange) {
        this.stockChange = stockChange;
    }

    public String getRate() {
        return rate;
    }

    public void setRate(String rate) {
        this.rate = rate;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getDetailDesc() {
        return detailDesc;
    }

    public void setDetailDesc(String detailDesc) {
        this.detailDesc = detailDesc;
    }

    public Integer getPayload() {
        return payload;
    }

    public void setPayload(Integer payload) {
        this.payload = payload;
    }

    public Integer getHidden() {
        return hidden;
    }

    public void setHidden(Integer hidden) {
        this.hidden = hidden;
    }

    public Boolean getIsDeleted() {
        return isDeleted;
    }

    public void setIsDeleted(Boolean isDeleted) {
        this.isDeleted = isDeleted;
    }
}

==> activity-center-api-0.7.4.4-20170622.074424-1-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/ActivityOptionDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto;

import cn.com.duiba.tuia.activity.center.api.common.BaseDto;

/**
 * ClassName: ActivityOptionDto <br/>
 * Function: 活动奖项Dto. <br/>
 * date: 2017年2月24日 下午2:17:46 <br/>
 *
 * @author wubo
 * @version 
 * @since JDK 1.7
 */
public class ActivityOptionDto extends BaseDto {

    private static final long serialVersionUID = -1115120469267768221L;
    private Long              id;                                      // 奖项id
    private Long              activityId;                              // 活动id
    private Integer           activityType;                            // 活动type
    private Long              advertId;                                // 广告id
    private Long              gid;                                     // 广告券id
    private Integer           gtype;                                   // 广告券类型
    private String            prizeType;                               // 奖项类型
    private String            image;                                   // 奖品图片url
    private String            detailImg;                               // 奖品详情图片 url
    private String            title;                                   // 奖品标题
    private Long              stockId;                                 // 剩余奖品数的库存id
    private Integer           stock;                                   // 库存值
    private Integer           stockChange;                             // 库存变化值
    private String            rate;                                    // 概率
    private String            description;                             // 奖品说明
    private String            detailDesc;                              // 奖品详情说明
    private Integer           payload;                                 // 排序权重
    private Integer           hidden;                                  // 奖品说明是否展示
    private Boolean           isDeleted;
    private Long              prizeId;                                 // 奖品id
    private Integer           guaranteedNum;                           // 保底人数
    private Integer           dayLimitNum;                             // 每日发奖限制

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Integer getActivityType() {
        return activityType;
    }

    public void setActivityType(Integer activityType) {
        this.activityType = activityType;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getGid() {
        return gid;
    }

    public void setGid(Long gid) {
        this.gid = gid;
    }

    public Integer getGtype() {
        return gtype;
    }

    public void setGtype(Integer gtype) {
        this.gtype = gtype;
    }

    public String getPrizeType() {
        return prizeType;
    }

    public void setPrizeType(String prizeType) {
        this.prizeType = prizeType;
    }

    public String getImage() {
        return image;
    }

    public void setImage(String image) {
        this.image = image;
    }

    public String getDetailImg() {
        return detailImg;
    }

    public void setDetailImg(String detailImg) {
        this.detailImg = detailImg;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Long getStockId() {
        return stockId;
    }

    public void setStockId(Long stockId) {
        this.stockId = stockId;
    }

    public Integer getStock() {
        return stock;
    }

    public void setStock(Integer stock) {
        this.stock = stock;
    }

    public Integer getStockChange() {
        return stockChange;
    }

    public void setStockChange(Integer stockChange) {
        this.stockChange = stockChange;
    }

    public String getRate() {
        return rate;
    }

    public void setRate(String rate) {
        this.rate = rate;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getDetailDesc() {
        return detailDesc;
    }

    public void setDetailDesc(String detailDesc) {
        this.detailDesc = detailDesc;
    }

    public Integer getPayload() {
        return payload;
    }

    public void setPayload(Integer payload) {
        this.payload = payload;
    }

    public Integer getHidden() {
        return hidden;
    }

    public void setHidden(Integer hidden) {
        this.hidden = hidden;
    }

    public Boolean getIsDeleted() {
        return isDeleted;
    }

    public void setIsDeleted(Boolean isDeleted) {
        this.isDeleted = isDeleted;
    }

    public Long getPrizeId() {
        return prizeId;
    }

    public void setPrizeId(Long prizeId) {
        this.prizeId = prizeId;
    }

    public Integer getGuaranteedNum() {
        return guaranteedNum;
    }

    public void setGuaranteedNum(Integer guaranteedNum) {
        this.guaranteedNum = guaranteedNum;
    }

    public Integer getDayLimitNum() {
        return dayLimitNum;
    }

    public void setDayLimitNum(Integer dayLimitNum) {
        this.dayLimitNum = dayLimitNum;
    }
}
